FileOpContextDelete class

Inheritance
Mixed-in types
Annotations
  • @MappableClass.new(discriminatorValue: 'delete')

Constructors

FileOpContextDelete({required String path})

Properties

copyWith FileOpContextDeleteCopyWith<FileOpContextDelete, FileOpContextDelete, FileOpContextDelete>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
path String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited