StringOpResponse class
- Inheritance
-
- Object
- OpResponse
- StringOpResponse
- Mixed-in types
- Annotations
-
- @MappableClass.new(ignoreNull: true, discriminatorValue: 'string')
Constructors
- StringOpResponse({required String response})
-
const
Properties
-
copyWith
→ StringOpResponseCopyWith<
StringOpResponse, StringOpResponse, StringOpResponse> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- response → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited